# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-28 21:16


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('segments', '0002_auto_20181026_1745'),
        ('sliders', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='SliderSegment',
            fields=[
                ('basesegment_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='segments.BaseSegment')),
            ],
            options={
                'verbose_name': 'Slider Segment',
                'verbose_name_plural': 'Sliders Segments',
            },
            bases=('segments.basesegment',),
        ),
    ]
