# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-28 16:12


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='page',
            name='english_title',
            field=models.CharField(default='home', max_length=100, verbose_name='English Title'),
            preserve_default=False,
        ),
    ]
