# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-02-01 19:15


import aparnik.utils.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('orders', '0009_orderitem_description'),
    ]

    operations = [
        migrations.AddField(
            model_name='order',
            name='postal_cost_value',
            field=aparnik.utils.fields.PriceField(decimal_places=0, default=0, max_digits=20, verbose_name='Postal Cost'),
        ),
    ]
