# -*- coding: utf-8 -*-


from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class CoSalesConfig(AppConfig):
    name = 'aparnik.packages.shops.cosales'
    verbose_name = _('Co Sales')
