{% load i18n static %}<!doctype html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport"
          content="width=device-width, user-scalable=no, initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <link rel="stylesheet" href="{% static "suit/css/style.css" %}">
    <title>404</title>
</head>
<body>
<div class="contaner">

    <div class="main">
        <div class="img_404">
            <img src="{% static "suit/img/404.png" %}">
        </div>
        <p class="text_404">متاسفیم,ما نتونستیم صفحه مورد نظر شما رو پیدا کنیم!</p>
        <div class="btn">
            <a href="/">منو از اینجا ببر</a>
        </div>

    </div>
</div>
</body>
</html>