# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-31 14:36


import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('vouchers', '0005_auto_20190130_1510'),
    ]

    operations = [
        migrations.AlterField(
            model_name='voucher',
            name='expire_at',
            field=models.DateTimeField(default=datetime.datetime(2300, 10, 5, 18, 0), verbose_name='Expire at'),
        ),
    ]
