# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-25 15:43


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('filefields', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='SocialNetwork',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('link', models.URLField(max_length=255, verbose_name='Link')),
                ('title', models.CharField(default=None, max_length=31, verbose_name='Title')),
                ('android_app_shortcut', models.CharField(blank=True, max_length=200, null=True, verbose_name='Android shortcut')),
                ('ios_app_shortcut', models.CharField(blank=True, max_length=200, null=True, verbose_name='iOS shortcut')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('update_at', models.DateTimeField(auto_now=True, verbose_name='Update at')),
                ('icon', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='filefields.FileField', verbose_name='Icon')),
            ],
            options={
                'verbose_name': 'Social Network',
                'verbose_name_plural': 'Social Networks',
            },
        ),
    ]
