# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-29 16:20


import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('vouchers', '0002_auto_20181203_1533'),
    ]

    operations = [
        migrations.AlterField(
            model_name='voucher',
            name='expire_at',
            field=models.DateTimeField(default=datetime.datetime(2219, 1, 29, 16, 20, 55, 692956), verbose_name='Expire at'),
        ),
    ]
