# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-06-13 18:14


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('basemodels', '0011_auto_20190612_1035'),
        ('reviews', '0004_reviewsummary_percentage'),
    ]

    operations = [
        migrations.AddField(
            model_name='review',
            name='model_obj2',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='reviews_set', to='basemodels.BaseModel', verbose_name='Model'),
        ),
    ]
