# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-21 09:49


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0008_alter_user_username_max_length'),
        ('managements', '0003_auto_20181126_1322'),
    ]

    operations = [
        migrations.AddField(
            model_name='fieldlist',
            name='group',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='auth.Group', verbose_name='group'),
            preserve_default=False,
        ),
    ]
