# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-04-23 11:06


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aparnik_users', '0021_auto_20190423_1058'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='company_economical_number',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Company economical number'),
        ),
    ]
