# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-09 21:39


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('province', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='city',
            options={'verbose_name': 'City', 'verbose_name_plural': 'Cities'},
        ),
        migrations.AlterModelOptions(
            name='province',
            options={'verbose_name': 'Province', 'verbose_name_plural': 'Provinces'},
        ),
        migrations.AlterModelOptions(
            name='shahrak',
            options={'verbose_name': 'Shahrak', 'verbose_name_plural': 'Shahraks'},
        ),
        migrations.AlterModelOptions(
            name='town',
            options={'verbose_name': 'Town', 'verbose_name_plural': 'Towns'},
        ),
        migrations.AlterField(
            model_name='city',
            name='province',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='province.Province', verbose_name='Province'),
        ),
        migrations.AlterField(
            model_name='city',
            name='title',
            field=models.CharField(max_length=255, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='province',
            name='title',
            field=models.CharField(max_length=100, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='shahrak',
            name='province',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='province.Province', verbose_name='Province'),
        ),
        migrations.AlterField(
            model_name='shahrak',
            name='title',
            field=models.TextField(verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='town',
            name='city',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='province.City', verbose_name='City'),
        ),
        migrations.AlterField(
            model_name='town',
            name='title',
            field=models.CharField(max_length=255, verbose_name='Title'),
        ),
    ]
