# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-08-05 16:26


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aparnik_users', '0002_user_passwd'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='verify_mobile',
            field=models.BooleanField(default=False, verbose_name='Verify Mobile'),
        ),
    ]
