# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-13 18:47


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0002_page_english_title'),
        ('segments', '0009_remove_basesegment_pages'),
    ]

    operations = [
        migrations.AddField(
            model_name='basesegment',
            name='pages',
            field=models.ManyToManyField(blank=True, related_name='segment_pages', through='segments.PageSort', to='pages.Page', verbose_name='\\u0635\\u0641\\u062d\\u0647'),
        ),
    ]
