# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-28 17:32


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('products', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='product',
            name='is_free',
            field=models.BooleanField(default=False, verbose_name='Is Free'),
        ),
    ]
