# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-14 13:30


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('courses', '0010_auto_20181205_1107'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='course',
            name='sort',
        ),
        migrations.RemoveField(
            model_name='coursefile',
            name='sort',
        ),
    ]
