# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-20 10:55


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('questionanswers', '0002_auto_20181026_1745'),
    ]

    operations = [
        migrations.AlterField(
            model_name='qa',
            name='files',
            field=models.ManyToManyField(blank=True, to='filefields.FileField', verbose_name='\\u0641\\u0627\\u06cc\\u0644 \\u0647\\u0627'),
        ),
    ]
