# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-25 15:43


import aparnik.utils.utils
from django.db import migrations, models
import django.db.models.deletion
import s3direct.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('basemodels', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='FileField',
            fields=[
                ('basemodel_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='basemodels.BaseModel')),
                ('file_s3', s3direct.fields.S3DirectField(blank=True, null=True, verbose_name='\\u067e\\u0631\\u0648\\u0646\\u062f\\u0647')),
                ('file_direct', models.FileField(blank=True, null=True, upload_to=aparnik.utils.utils.document_directory_path, verbose_name='\\u067e\\u0631\\u0648\\u0646\\u062f\\u0647')),
                ('size', models.IntegerField(verbose_name='File Size')),
                ('type', models.CharField(choices=[('M', 'Movie'), ('V', 'Voice'), ('P', 'PDF'), ('I', '\\u062a\\u0635\\u0648\\u06cc\\u0631')], max_length=1, verbose_name='File Type')),
            ],
            options={
                'verbose_name': 'File Field',
                'verbose_name_plural': 'Files Field',
            },
            bases=('basemodels.basemodel',),
        ),
    ]
